@@ -5,7 +5,7 @@
 
 import tempfile
 import unittest
-import mock
+from unittest import mock
 import multiprocessing
 import configparser
 
