@@ -20,8 +20,8 @@ from ._completers import (
 from ._validators import (
     validate_create_parameters, validate_kubectl_version, validate_kubelogin_version, validate_k8s_version, validate_linux_host_name,
     validate_list_of_integers, validate_ssh_key, validate_nodes_count,
-    validate_nodepool_name, validate_vm_set_type, validate_load_balancer_sku, validate_load_balancer_outbound_ips,
-    validate_priority, validate_eviction_policy, validate_spot_max_price,
+    validate_nodepool_name, validate_vm_set_type, validate_load_balancer_sku, validate_nodepool_id, validate_snapshot_id,
+    validate_load_balancer_outbound_ips, validate_priority, validate_eviction_policy, validate_spot_max_price,
     validate_load_balancer_outbound_ip_prefixes, validate_taints, validate_ip_ranges, validate_acr, validate_nodepool_tags,
     validate_load_balancer_outbound_ports, validate_load_balancer_idle_timeout, validate_vnet_subnet_id, validate_nodepool_labels,
     validate_ppg, validate_assign_identity, validate_max_surge, validate_assign_kubelet_identity)
@@ -303,6 +303,7 @@ def load_arguments(self, _):
                    '--yes', '-y'], help='Do not prompt for confirmation.', action='store_true')
         c.argument('enable_sgxquotehelper', action='store_true')
         c.argument('enable_fips_image', action='store_true')
+        c.argument('snapshot_id', validator=validate_snapshot_id)
 
     with self.argument_context('aks update', resource_type=ResourceType.MGMT_CONTAINERSERVICE, operation_group='managed_clusters') as c:
         c.argument('attach_acr', acr_arg_type, validator=validate_acr)
@@ -452,12 +453,16 @@ def load_arguments(self, _):
             c.argument('enable_ultra_ssd', options_list=[
                        '--enable-ultra-ssd'], action='store_true')
             c.argument('enable_fips_image', action='store_true')
+            c.argument('snapshot_id', validator=validate_snapshot_id)
 
     for scope in ['aks nodepool show', 'aks nodepool delete', 'aks nodepool scale', 'aks nodepool upgrade', 'aks nodepool update']:
         with self.argument_context(scope) as c:
             c.argument('nodepool_name', type=str, options_list=[
                        '--name', '-n'], validator=validate_nodepool_name, help='The node pool name.')
 
+    with self.argument_context('aks nodepool upgrade') as c:
+        c.argument('snapshot_id', validator=validate_snapshot_id)
+
     with self.argument_context('aks nodepool update', resource_type=ResourceType.MGMT_CONTAINERSERVICE, operation_group='agent_pools') as c:
         c.argument('enable_cluster_autoscaler', options_list=[
                    "--enable-cluster-autoscaler", "-e"], action='store_true')
@@ -512,6 +517,18 @@ def load_arguments(self, _):
         c.argument(
             'workspace_id', help='The resource ID of an existing Log Analytics Workspace to use for storing monitoring data.')
 
+    for scope in ['aks snapshot create']:
+        with self.argument_context(scope) as c:
+            c.argument('snapshot_name', options_list=['--name', '-n'], required=True, validator=validate_linux_host_name, help='The snapshot name.')
+            c.argument('tags', tags_type)
+            c.argument('nodepool_id', required=True, validator=validate_nodepool_id, help='The nodepool id.')
+            c.argument('aks_custom_headers')
+
+    for scope in ['aks snapshot show', 'aks snapshot delete']:
+        with self.argument_context(scope) as c:
+            c.argument('snapshot_name', options_list=['--name', '-n'], required=True, validator=validate_linux_host_name, help='The snapshot name.')
+            c.argument('yes', options_list=['--yes', '-y'], help='Do not prompt for confirmation.', action='store_true')
+
 
 def _get_default_install_location(exe_name):
     system = platform.system()
