@@ -12,6 +12,7 @@ from ._client_factory import cf_container_services
 from ._client_factory import cf_managed_clusters
 from ._client_factory import cf_agent_pools
 from ._client_factory import cf_openshift_managed_clusters
+from ._client_factory import cf_snapshots
 from ._format import aks_list_table_format
 from ._format import aks_show_table_format
 from ._format import aks_agentpool_show_table_format
@@ -20,6 +21,8 @@ from ._format import osa_list_table_format
 from ._format import aks_upgrades_table_format
 from ._format import aks_versions_table_format
 from ._format import aks_run_command_result_format
+from ._format import aks_show_snapshot_table_format
+from ._format import aks_list_snapshot_table_format
 
 
 # pylint: disable=too-many-statements
@@ -48,6 +51,12 @@ def load_command_table(self, _):
         client_factory=cf_managed_clusters
     )
 
+    snapshot_sdk = CliCommandType(
+        operations_tmpl='azext_aks_preview.vendored_sdks.azure_mgmt_preview_aks.'
+                        'operations._snapshots_operations#SnapshotsOperations.{}',
+        client_factory=cf_snapshots
+    )
+
     openshift_managed_clusters_sdk = CliCommandType(
         operations_tmpl='azure.mgmt.containerservice.operations.'
                         '_open_shift_managed_clusters_operations#OpenShiftManagedClustersOperations.{}',
@@ -148,6 +157,13 @@ def load_command_table(self, _):
         g.custom_command('result', 'aks_command_result',
                          supports_no_wait=False, table_transformer=aks_run_command_result_format)
 
+    # AKS snapshot commands
+    with self.command_group('aks snapshot', snapshot_sdk, client_factory=cf_snapshots) as g:
+        g.custom_command('list', 'aks_snapshot_list', table_transformer=aks_list_snapshot_table_format)
+        g.custom_show_command('show', 'aks_snapshot_show', table_transformer=aks_show_snapshot_table_format)
+        g.custom_command('create', 'aks_snapshot_create', supports_no_wait=True)
+        g.custom_command('delete', 'aks_snapshot_delete', supports_no_wait=True)
+
     # OSA commands
     with self.command_group('openshift', openshift_managed_clusters_sdk,
                             client_factory=cf_openshift_managed_clusters,
