@@ -10,7 +10,7 @@ NODE_EXACT_VERSION_DEFAULT = "10.14.1"
 NETCORE_VERSION_DEFAULT = "3.1"
 ASPDOTNET_VERSION_DEFAULT = "4.8"
 DOTNET_VERSION_DEFAULT = "5.0"
-DOTNET_TARGET_FRAMEWORK_STRING = "net5.0"
+DOTNET_TARGET_FRAMEWORK_REGEX = r"^net\d+\.\d+$"
 PYTHON_VERSION_DEFAULT = "3.7"
 NETCORE_RUNTIME_NAME = "dotnetcore"
 ASPDOTNET_RUNTIME_NAME = "aspnet"
@@ -22,7 +22,8 @@ STATIC_RUNTIME_NAME = "static"  # not an official supported runtime but used for
 NODE_VERSIONS = ['10.6', '10.14']
 PYTHON_VERSIONS = ['3.9', '3.8', '3.7', '3.6']
 NETCORE_VERSIONS = ['2.1', '3.1']
-DOTNET_VERSIONS = ['3.5', '4.8']
+DOTNET_VERSIONS = ['5.0', '6.0']
+ASPDOTNET_VERSIONS = ['3.5', '4.8']
 LINUX_SKU_DEFAULT = "P1V2"
 FUNCTIONS_VERSIONS = ['2', '3', '4']
 FUNCTIONS_STACKS_API_JSON_PATHS = {
