@@ -5,19 +5,19 @@
 
 import ipaddress
 
-from azure.cli.core.azclierror import (InvalidArgumentValueError, ArgumentUsageError, ValidationError,
-                                       MutuallyExclusiveArgumentError)
-from azure.cli.core.commands.client_factory import get_mgmt_service_client
+
+from azure.cli.core.azclierror import (InvalidArgumentValueError, ArgumentUsageError, RequiredArgumentMissingError,
+                                       ResourceNotFoundError, ValidationError, MutuallyExclusiveArgumentError)
+from azure.cli.core.commands.client_factory import get_mgmt_service_client, get_subscription_id
 from azure.cli.core.profiles import ResourceType
 from azure.cli.core.commands.validators import validate_tags
 
 from knack.log import get_logger
-from knack.util import CLIError
 from msrestazure.tools import is_valid_resource_id, parse_resource_id
 
 from ._appservice_utils import _generic_site_operation
 from ._client_factory import web_client_factory
-from .utils import _normalize_sku, get_sku_name
+from .utils import _normalize_sku, get_sku_tier, _normalize_location
 
 logger = get_logger(__name__)
 
@@ -59,7 +59,8 @@ def validate_site_create(cmd, namespace):
         else:
             plan_info = client.app_service_plans.get(resource_group_name, plan)
         if not plan_info:
-            raise CLIError("The plan '{}' doesn't exist in the resource group '{}'".format(plan, resource_group_name))
+            raise ResourceNotFoundError("The plan '{}' doesn't exist in the resource group '{}'".format(
+                plan, resource_group_name))
         # verify that the name is available for create
         validation_payload = {
             "name": namespace.name,
@@ -71,7 +72,7 @@ def validate_site_create(cmd, namespace):
         }
         validation = client.validate(resource_group_name, validation_payload)
         if validation.status.lower() == "failure" and validation.error.code != 'SiteAlreadyExists':
-            raise CLIError(validation.error.message)
+            raise ValidationError(validation.error.message)
 
 
 def validate_ase_create(cmd, namespace):
@@ -81,11 +82,11 @@ def validate_ase_create(cmd, namespace):
     if isinstance(namespace.name, str):
         name_validation = client.check_name_availability(namespace.name, resource_type)
         if not name_validation.name_available:
-            raise CLIError(name_validation.message)
+            raise ValidationError(name_validation.message)
 
 
 def _validate_asp_sku(sku, app_service_environment, zone_redundant):
-    if zone_redundant and get_sku_name(sku.upper()) not in ['PREMIUMV2', 'PREMIUMV3']:
+    if zone_redundant and get_sku_tier(sku.upper()) not in ['PREMIUMV2', 'PREMIUMV3']:
         raise ValidationError("Zone redundancy cannot be enabled for sku {}".format(sku))
     # Isolated SKU is supported only for ASE
     if sku.upper() in ['I1', 'I2', 'I3', 'I1V2', 'I2V2', 'I3V2']:
@@ -110,7 +111,7 @@ def validate_asp_create(namespace):
 def validate_functionapp_asp_create(namespace):
     validate_tags(namespace)
     sku = _normalize_sku(namespace.sku)
-    tier = get_sku_name(sku)
+    tier = get_sku_tier(sku)
     _validate_asp_sku(sku=sku, app_service_environment=None, zone_redundant=namespace.zone_redundant)
     if namespace.max_burst is not None:
         if tier.lower() != "elasticpremium":
@@ -131,7 +132,7 @@ def validate_app_or_slot_exists_in_rg(cmd, namespace):
     else:
         app = client.web_apps.get(resource_group_name, webapp, None, raw=True)
     if app.response.status_code != 200:
-        raise CLIError(app.response.text)
+        raise ResourceNotFoundError(app.response.text)
 
 
 def validate_app_exists_in_rg(cmd, namespace):
@@ -140,31 +141,59 @@ def validate_app_exists_in_rg(cmd, namespace):
     resource_group_name = namespace.resource_group_name
     app = client.web_apps.get(resource_group_name, webapp, None, raw=True)
     if app.response.status_code != 200:
-        raise CLIError(app.response.text)
+        raise ResourceNotFoundError(app.response.text)
 
 
 def validate_add_vnet(cmd, namespace):
+    from azure.core.exceptions import ResourceNotFoundError as ResNotFoundError
+
     resource_group_name = namespace.resource_group_name
     from azure.cli.command_modules.network._client_factory import network_client_factory
-    vnet_client = network_client_factory(cmd.cli_ctx)
-    list_all_vnets = vnet_client.virtual_networks.list_all()
-    vnet = namespace.vnet
+
+    vnet_identifier = namespace.vnet
     name = namespace.name
     slot = namespace.slot
 
-    vnet_loc = ''
-    for v in list_all_vnets:
-        if vnet in (v.name, v.id):
-            vnet_loc = v.location
-            break
+    if is_valid_resource_id(vnet_identifier):
+        current_sub_id = get_subscription_id(cmd.cli_ctx)
+        parsed_vnet = parse_resource_id(vnet_identifier)
+
+        vnet_sub_id = parsed_vnet['subscription']
+        vnet_group = parsed_vnet['resource_group']
+        vnet_name = parsed_vnet['name']
+
+        cmd.cli_ctx.data['subscription_id'] = vnet_sub_id
+        vnet_client = network_client_factory(cmd.cli_ctx)
+        vnet_loc = vnet_client.virtual_networks.get(resource_group_name=vnet_group,
+                                                    virtual_network_name=vnet_name).location
+        cmd.cli_ctx.data['subscription_id'] = current_sub_id
+    else:
+        vnet_client = network_client_factory(cmd.cli_ctx)
+
+        try:
+            vnet_loc = vnet_client.virtual_networks.get(resource_group_name=namespace.resource_group_name,
+                                                        virtual_network_name=vnet_identifier).location
+        except ResNotFoundError:
+            vnets = vnet_client.virtual_networks.list_all()
+            vnet_loc = ''
+            for v in vnets:
+                if vnet_identifier == v.name:
+                    vnet_loc = v.location
+                    break
+
+    if not vnet_loc:
+        # Fall back to back end validation
+        logger.warning("Failed to fetch vnet. Skipping location validation.")
+        return
 
     webapp = _generic_site_operation(cmd.cli_ctx, resource_group_name, name, 'get', slot)
-    # converting geo region to geo location
-    webapp_loc = webapp.location.lower().replace(" ", "")
+
+    webapp_loc = _normalize_location(cmd, webapp.location)
+    vnet_loc = _normalize_location(cmd, vnet_loc)
 
     if vnet_loc != webapp_loc:
-        raise CLIError("The app and the vnet resources are in different locations. \
-                        Cannot integrate a regional VNET to an app in a different region")
+        raise ValidationError("The app and the vnet resources are in different locations. "
+                              "Cannot integrate a regional VNET to an app in a different region")
 
 
 def validate_front_end_scale_factor(namespace):
@@ -174,7 +203,7 @@ def validate_front_end_scale_factor(namespace):
         scale_error_text = "Frontend Scale Factor '{}' is invalid. Must be between {} and {}"
         scale_factor = namespace.front_end_scale_factor
         if scale_factor < min_scale_factor or scale_factor > max_scale_factor:
-            raise CLIError(scale_error_text.format(scale_factor, min_scale_factor, max_scale_factor))
+            raise ValidationError(scale_error_text.format(scale_factor, min_scale_factor, max_scale_factor))
 
 
 def validate_ip_address(cmd, namespace):
@@ -187,13 +216,13 @@ def validate_ip_address(cmd, namespace):
 
 def validate_onedeploy_params(namespace):
     if namespace.src_path and namespace.src_url:
-        raise CLIError('Only one of --src-path and --src-url can be specified')
+        raise MutuallyExclusiveArgumentError('Only one of --src-path and --src-url can be specified')
 
     if not namespace.src_path and not namespace.src_url:
-        raise CLIError('Either of --src-path or --src-url must be specified')
+        raise RequiredArgumentMissingError('Either of --src-path or --src-url must be specified')
 
     if namespace.src_url and not namespace.artifact_type:
-        raise CLIError('Deployment type is mandatory when deploying from URLs. Use --type')
+        raise RequiredArgumentMissingError('Deployment type is mandatory when deploying from URLs. Use --type')
 
 
 def _validate_ip_address_format(namespace):
@@ -276,7 +305,7 @@ def _validate_service_tag_existence(cmd, namespace):
 def validate_public_cloud(cmd):
     from azure.cli.core.cloud import AZURE_PUBLIC_CLOUD
     if cmd.cli_ctx.cloud.name != AZURE_PUBLIC_CLOUD.name:
-        raise CLIError('This command is not yet supported on soveriegn clouds.')
+        raise ValidationError('This command is not yet supported on soveriegn clouds.')
 
 
 def validate_staticsite_sku(cmd, namespace):
@@ -305,6 +334,7 @@ def validate_staticsite_link_function(cmd, namespace):
         raise ValidationError("Cannot have more than one user provided function app associated with a Static Web App")
 
 
+# TODO consider combining with validate_add_vnet
 def validate_vnet_integration(cmd, namespace):
     validate_tags(namespace)
     if namespace.subnet or namespace.vnet:
@@ -323,7 +353,7 @@ def validate_vnet_integration(cmd, namespace):
 
         sku_name = plan_info.sku.name
         disallowed_skus = {'FREE', 'SHARED', 'BASIC', 'ElasticPremium', 'PremiumContainer', 'Isolated', 'IsolatedV2'}
-        if get_sku_name(sku_name) in disallowed_skus:
+        if get_sku_tier(sku_name) in disallowed_skus:
             raise ArgumentUsageError("App Service Plan has invalid sku for vnet integration: {}."
                                      "Plan sku cannot be one of: {}. "
                                      "Please run 'az appservice plan create -h' "
