@@ -3,12 +3,11 @@
 # Licensed under the MIT License. See License.txt in the project root for license information.
 # --------------------------------------------------------------------------------------------
 import unittest
-import mock
+from unittest import mock
 
 from msrestazure.azure_exceptions import CloudError
 
 from azure.mgmt.web import WebSiteManagementClient
-from azure.cli.core.adal_authentication import AdalAuthentication
 from knack.util import CLIError
 from azure.cli.command_modules.appservice.custom import (set_deployment_user,
                                                          update_git_token, add_hostname,
@@ -19,7 +18,6 @@ from azure.cli.command_modules.appservice.custom import (set_deployment_user,
                                                          _match_host_names_from_cert,
                                                          bind_ssl_cert,
                                                          list_publish_profiles,
-                                                         config_source_control,
                                                          show_webapp,
                                                          get_streaming_log,
                                                          download_historical_logs,
@@ -30,7 +28,6 @@ from azure.cli.command_modules.appservice.custom import (set_deployment_user,
                                                          create_managed_ssl_cert)
 
 # pylint: disable=line-too-long
-from vsts_cd_manager.continuous_delivery_manager import ContinuousDeliveryResult
 from azure.cli.core.profiles import ResourceType
 
 
@@ -48,7 +45,7 @@ def _get_test_cmd():
 
 class TestWebappMocked(unittest.TestCase):
     def setUp(self):
-        self.client = WebSiteManagementClient(AdalAuthentication(lambda: ('bearer', 'secretToken')), '123455678')
+        self.client = WebSiteManagementClient(mock.MagicMock(), '123455678')
 
     @mock.patch('azure.cli.command_modules.appservice.custom.web_client_factory', autospec=True)
     def test_set_deployment_user_creds(self, client_factory_mock):
@@ -99,12 +96,19 @@ class TestWebappMocked(unittest.TestCase):
                                   custom_host_name_dns_record_type='A',
                                   host_name_type='Managed')
         client.web_apps.create_or_update_host_name_binding.return_value = binding
+        client.web_apps.create_or_update_host_name_binding_slot.return_value = binding
         # action
         result = add_hostname(cmd_mock, 'g1', webapp.name, domain)
 
         # assert
         self.assertEqual(result.domain_id, domain)
 
+         # action- Slot
+        result = add_hostname(cmd_mock, 'g1', webapp.name, domain, 'slot1')
+
+        # assert
+        self.assertEqual(result.domain_id, domain)
+
     @mock.patch('azure.cli.command_modules.appservice.custom.web_client_factory', autospec=True)
     def test_get_external_ip_from_ase(self, client_factory_mock):
         client = mock.Mock()
@@ -172,49 +176,6 @@ class TestWebappMocked(unittest.TestCase):
         # assert, we return the virtual ip from the ip based ssl binding
         resolve_hostname_mock.assert_called_with('myweb.com')
 
-    @mock.patch('azure.cli.command_modules.appservice.custom.web_client_factory', autospec=True)
-    @mock.patch('azure.cli.command_modules.appservice.vsts_cd_provider.ContinuousDeliveryManager', autospec=True)
-    @mock.patch('azure.cli.command_modules.appservice.vsts_cd_provider.Profile', autospec=True)
-    def test_config_source_control_vsts(self, profile_mock, cd_manager_mock, client_factory_mock):
-        # Mock the result of get auth token (avoiding REST call)
-        profile = mock.Mock()
-        profile.get_subscription.return_value = {'id': 'id1', 'name': 'sub1', 'tenantId': 'tenant1'}
-        profile.get_current_account_user.return_value = None
-        profile.get_login_credentials.return_value = None, None, None
-        profile.get_access_token_for_resource.return_value = None
-        profile_mock.return_value = profile
-
-        # Mock the cd manager class so no REST calls are made
-        cd_manager = mock.Mock()
-        status = ContinuousDeliveryResult(None, None, None, None, None, None, "message1", None,
-                                          None, None)
-        cd_manager.setup_continuous_delivery.return_value = status
-        cd_manager_mock.return_value = cd_manager
-
-        # Mock the client and set the location
-        client = mock.Mock()
-        client_factory_mock.return_value = client
-        cmd_mock = _get_test_cmd()
-        Site = cmd_mock.get_models('Site')
-        site = Site(name='antarctica', location='westus')
-        site.default_host_name = 'myweb.com'
-        client.web_apps.get.return_value = site
-
-        config_source_control(mock.MagicMock(), 'group1', 'myweb', 'http://github.com/repo1', None, None, None,
-                              None, None, 'ASPNet', 'working_directory', 'Gulp', 'Django',
-                              'Python 2.7.12 x64', True, 'https://account1.visualstudio.com',
-                              None, 'slot1', None, None)
-        cd_app_type_details = {
-            'cd_app_type': 'ASPNet',
-            'app_working_dir': 'working_directory',
-            'nodejs_task_runner': 'Gulp',
-            'python_framework': 'Django',
-            'python_version': 'Python 2.7.12 x64'
-        }
-        cd_manager.setup_continuous_delivery.assert_called_with('slot1', cd_app_type_details,
-                                                                'https://account1.visualstudio.com',
-                                                                True, None, None, None)
-
     @mock.patch('azure.cli.command_modules.appservice.custom._generic_site_operation', autospec=True)
     def test_update_site_config(self, site_op_mock):
         cmd_mock = _get_test_cmd()
@@ -236,7 +197,8 @@ class TestWebappMocked(unittest.TestCase):
         # action
         result = list_publish_profiles(mock.MagicMock(), 'myRG', 'myweb', 'slot1')
         # assert
-        site_op_mock.assert_called_with(mock.ANY, 'myRG', 'myweb', 'list_publishing_profile_xml_with_secrets', 'slot1')
+        site_op_mock.assert_called_with(mock.ANY, 'myRG', 'myweb', 'list_publishing_profile_xml_with_secrets', 'slot1',
+                                        {'format': 'WebDeploy'})
         self.assertTrue(result[0]['publishUrl'].startswith('ftp://123'))
 
     @mock.patch('azure.cli.command_modules.appservice.custom._generic_site_operation', autospec=True)
@@ -265,7 +227,7 @@ class TestWebappMocked(unittest.TestCase):
         faked_web = mock.MagicMock()
         site_op_mock.return_value = faked_web
         # action
-        result = show_webapp(mock.MagicMock(), 'myRG', 'myweb', slot=None, app_instance=None)
+        result = show_webapp(mock.MagicMock(), 'myRG', 'myweb', slot=None)
         # assert (we invoke the site op)
         self.assertEqual(faked_web, result)
         self.assertTrue(rename_mock.called)
@@ -309,7 +271,7 @@ class TestWebappMocked(unittest.TestCase):
             self.fail('test exception was not thrown')
         except ErrorToExitInfiniteLoop:
             # assert
-            site_op_mock.assert_called_with(cli_ctx_mock, 'rg', 'web1', 'list_publishing_credentials', None)
+            site_op_mock.assert_called_with(cli_ctx_mock, 'rg', 'web1', 'begin_list_publishing_credentials', None)
 
     @mock.patch('azure.cli.command_modules.appservice.custom._generic_site_operation', autospec=True)
     def test_restore_deleted_webapp(self, site_op_mock):
@@ -323,7 +285,7 @@ class TestWebappMocked(unittest.TestCase):
         restore_deleted_webapp(cmd_mock, '12345', 'rg', 'web1', None, True)
 
         # assert
-        site_op_mock.assert_called_with(cli_ctx_mock, 'rg', 'web1', 'restore_from_deleted_app', None, request)
+        site_op_mock.assert_called_with(cli_ctx_mock, 'rg', 'web1', 'begin_restore_from_deleted_app', None, request)
 
     @mock.patch('azure.cli.command_modules.appservice.custom._generic_site_operation', autospec=True)
     def test_list_webapp_snapshots(self, site_op_mock):
@@ -386,7 +348,7 @@ class TestWebappMocked(unittest.TestCase):
         download_historical_logs(cmd_mock, 'rg', 'web1')
 
         # assert
-        site_op_mock.assert_called_with(cli_ctx_mock, 'rg', 'web1', 'list_publishing_credentials', None)
+        site_op_mock.assert_called_with(cli_ctx_mock, 'rg', 'web1', 'begin_list_publishing_credentials', None)
         get_log_mock.assert_called_with(test_scm_url + '/dump', 'great_user', 'secret_password', None)
 
     def test_valid_linux_create_options(self):
