@@ -5,7 +5,6 @@
 
 from typing import Optional
 
-
 from azure.mgmt.cdn.models import (Endpoint, SkuName, EndpointUpdateParameters, ProfileUpdateParameters,
                                    MinimumTlsVersion, EndpointPropertiesUpdateParametersDeliveryPolicy, DeliveryRule,
                                    DeliveryRuleRemoteAddressCondition, RemoteAddressMatchConditionParameters,
@@ -25,16 +24,26 @@ from azure.mgmt.cdn.models import (Endpoint, SkuName, EndpointUpdateParameters,
                                    DeliveryRuleCacheExpirationAction, CacheExpirationActionParameters,
                                    DeliveryRuleRequestHeaderAction, HeaderActionParameters,
                                    DeliveryRuleResponseHeaderAction, DeliveryRuleCacheKeyQueryStringAction,
-                                   CacheKeyQueryStringActionParameters, UrlRedirectAction,
-                                   DeliveryRuleAction, UrlRedirectActionParameters,
-                                   UrlRewriteAction, UrlRewriteActionParameters)
+                                   CacheKeyQueryStringActionParameters, UrlRedirectAction, ValidateCustomDomainInput,
+                                   DeliveryRuleAction, UrlRedirectActionParameters, LoadParameters,
+                                   UrlRewriteAction, UrlRewriteActionParameters, PurgeParameters,
+                                   CheckNameAvailabilityInput, CustomDomainParameters, ProbeProtocol,
+                                   HealthProbeRequestType, RequestMethodOperator, OriginGroupOverrideAction,
+                                   OriginGroupOverrideActionParameters, ResourceReference)
 
+from azure.mgmt.cdn.models._cdn_management_client_enums import CacheType
 from azure.mgmt.cdn.operations import (OriginsOperations, OriginGroupsOperations)
 
+from azure.cli.core.commands.client_factory import get_subscription_id
 from azure.cli.core.util import (sdk_no_wait)
+from azure.core.exceptions import (ResourceNotFoundError)
+
 from knack.util import CLIError
 from knack.log import get_logger
 
+from msrest.polling import LROPoller, NoPolling
+from msrestazure.tools import is_valid_resource_id
+
 logger = get_logger(__name__)
 
 
@@ -56,12 +65,72 @@ def _update_mapper(existing, new, keys):
         setattr(new, key, new_value if new_value is not None else existing_value)
 
 
+def _convert_to_unified_delivery_rules(policy):
+    for existing_rule in policy.rules:
+        if existing_rule.conditions:
+            for con in existing_rule.conditions:
+                if con.parameters.operator is None and con.parameters.match_values is None:
+                    if con.parameters.odata_type == UrlPathMatchConditionParameters.odata_type:
+                        con.parameters.operator = con.parameters.additional_properties["matchType"]
+                        con.parameters.match_values = con.parameters.additional_properties["path"].split(',')
+                    if con.parameters.odata_type == UrlFileExtensionMatchConditionParameters.odata_type:
+                        con.parameters.operator = "Any"
+                        con.parameters.match_values = con.parameters.additional_properties["extensions"]
+
+
 # region Custom Commands
 def list_profiles(client, resource_group_name=None):
     profiles = client.profiles
     profile_list = profiles.list_by_resource_group(resource_group_name=resource_group_name) \
         if resource_group_name else profiles.list()
-    return list(profile_list)
+
+    return [profile for profile in profile_list if profile.sku.name not in
+            (SkuName.premium_azure_front_door, SkuName.standard_azure_front_door)]
+
+
+def check_name_availability(client, name):
+    """Check the availability of a resource name. This is needed for resources
+    where name is globally unique, such as a CDN endpoint.
+    :param name: The resource name to validate.
+    :type name: str
+    """
+
+    validate_input = CheckNameAvailabilityInput(name=name)
+
+    return client.check_name_availability(validate_input)
+
+
+def validate_custom_domain(client, resource_group_name, profile_name, endpoint_name, host_name):
+    validate_input = ValidateCustomDomainInput(host_name=host_name)
+
+    return client.endpoints.validate_custom_domain(resource_group_name, profile_name, endpoint_name, validate_input)
+
+
+def get_profile(client, resource_group_name, profile_name):
+    profile = client.profiles.get(resource_group_name, profile_name)
+    if profile.sku.name in (SkuName.premium_azure_front_door, SkuName.standard_azure_front_door):
+        # Workaround to make the behavior consist with true "Not Found"
+        logger.warning('Standard_AzureFrontDoor and Premium_AzureFrontDoor are only supported for AFD profiles')
+        raise ResourceNotFoundError("Operation returned an invalid status code 'Not Found'")
+
+    return profile
+
+
+def delete_profile(client, resource_group_name, profile_name):
+    profile = None
+    try:
+        profile = client.profiles.get(resource_group_name, profile_name)
+    except ResourceNotFoundError:
+        pass
+
+    if profile is None or profile.sku.name in (SkuName.premium_azure_front_door, SkuName.standard_azure_front_door):
+        def get_long_running_output(_):
+            return None
+
+        logger.warning('Standard_AzureFrontDoor and Premium_AzureFrontDoor are only supported for AFD profiles')
+        return LROPoller(client, None, get_long_running_output, NoPolling())
+
+    return client.profiles.begin_delete(resource_group_name, profile_name)
 
 
 def update_endpoint(instance,
@@ -75,8 +144,6 @@ def update_endpoint(instance,
                     default_origin_group=None,
                     tags=None):
 
-    from azure.mgmt.cdn.models import ResourceReference
-
     # default origin group is specified as a name, format it as an ID.
     if default_origin_group is not None:
         if '/' not in default_origin_group:
@@ -127,7 +194,8 @@ def create_condition(match_variable=None, operator=None, match_values=None,
         return DeliveryRuleRequestMethodCondition(
             parameters=RequestMethodMatchConditionParameters(
                 match_values=match_values,
-                negate_condition=negate_condition
+                negate_condition=negate_condition,
+                operator=RequestMethodOperator.EQUAL
             ))
     if match_variable == 'QueryString':
         return DeliveryRuleQueryStringCondition(
@@ -175,7 +243,8 @@ def create_condition(match_variable=None, operator=None, match_values=None,
         return DeliveryRuleRequestSchemeCondition(
             parameters=RequestSchemeMatchConditionParameters(
                 match_values=match_values,
-                negate_condition=negate_condition
+                negate_condition=negate_condition,
+                operator=RequestMethodOperator.EQUAL
             ))
     if match_variable == 'UrlPath':
         return DeliveryRuleUrlPathCondition(
@@ -205,13 +274,15 @@ def create_condition(match_variable=None, operator=None, match_values=None,
         return DeliveryRuleHttpVersionCondition(
             parameters=HttpVersionMatchConditionParameters(
                 match_values=match_values,
-                negate_condition=negate_condition
+                negate_condition=negate_condition,
+                operator=RequestMethodOperator.EQUAL
             ))
     if match_variable == 'IsDevice':
         return DeliveryRuleIsDeviceCondition(
             parameters=IsDeviceMatchConditionParameters(
                 match_values=match_values,
-                negate_condition=negate_condition
+                negate_condition=negate_condition,
+                operator=RequestMethodOperator.EQUAL
             ))
     if match_variable == 'Cookies':
         return DeliveryRuleCookiesCondition(
@@ -230,21 +301,23 @@ def create_action(action_name, cache_behavior=None, cache_duration=None, header_
                   header_name=None, header_value=None, query_string_behavior=None, query_parameters=None,
                   redirect_type=None, redirect_protocol=None, custom_hostname=None, custom_path=None,
                   custom_query_string=None, custom_fragment=None, source_pattern=None, destination=None,
-                  preserve_unmatched_path=None):
+                  preserve_unmatched_path=None, cmd=None, resource_group_name=None, profile_name=None,
+                  endpoint_name=None, origin_group=None):
     if action_name == "CacheExpiration":
         return DeliveryRuleCacheExpirationAction(
             parameters=CacheExpirationActionParameters(
                 cache_behavior=cache_behavior,
-                cache_duration=cache_duration
+                cache_duration=cache_duration,
+                cache_type=CacheType.ALL
             ))
-    if action_name == 'RequestHeader':
+    if action_name in ('RequestHeader', 'ModifyRequestHeader'):
         return DeliveryRuleRequestHeaderAction(
             parameters=HeaderActionParameters(
                 header_action=header_action,
                 header_name=header_name,
                 value=header_value
             ))
-    if action_name == 'ResponseHeader':
+    if action_name in ('ResponseHeader', 'ModifyResponseHeader'):
         return DeliveryRuleResponseHeaderAction(
             parameters=HeaderActionParameters(
                 header_action=header_action,
@@ -274,25 +347,47 @@ def create_action(action_name, cache_behavior=None, cache_duration=None, header_
                 destination=destination,
                 preserve_unmatched_path=preserve_unmatched_path
             ))
+    if action_name == 'OriginGroupOverride':
+        if not is_valid_resource_id(origin_group):
+            # Ideally we should use resource_id but Auzre FrontDoor portal extension has some case-sensitive issues
+            # that prevent it from displaying correctly in portal.
+            origin_group = f'/subscriptions/{get_subscription_id(cmd.cli_ctx)}/resourcegroups/{resource_group_name}' \
+                           f'/providers/Microsoft.Cdn/profiles/{profile_name}/endpoints/{endpoint_name}' \
+                           f'/origingroups/{origin_group.lower()}'
+
+        return OriginGroupOverrideAction(
+            parameters=OriginGroupOverrideActionParameters(
+                origin_group=ResourceReference(id=origin_group)
+            ))
+
     return DeliveryRuleAction()
 
 
 # pylint: disable=too-many-locals
-def add_rule(client, resource_group_name, profile_name, endpoint_name,
-             order, rule_name, action_name, match_variable=None, operator=None,
+def add_rule(cmd, client, resource_group_name, profile_name, endpoint_name,
+             order, action_name, match_variable=None, operator=None,
              match_values=None, selector=None, negate_condition=None, transform=None,
              cache_behavior=None, cache_duration=None, header_action=None,
              header_name=None, header_value=None, query_string_behavior=None, query_parameters=None,
              redirect_type=None, redirect_protocol=None, custom_hostname=None, custom_path=None,
              custom_querystring=None, custom_fragment=None, source_pattern=None,
-             destination=None, preserve_unmatched_path=None):
+             destination=None, preserve_unmatched_path=None, rule_name=None, origin_group=None):
+
+    partner_skus = [SkuName.PREMIUM_VERIZON, SkuName.CUSTOM_VERIZON, SkuName.STANDARD_AKAMAI, SkuName.STANDARD_VERIZON]
+    profile = client.profiles.get(resource_group_name, profile_name)
+    if rule_name is None and profile.sku.name not in partner_skus:
+        raise CLIError("--rule-name is required for Microsoft SKU")
+
     endpoint = client.endpoints.get(resource_group_name, profile_name, endpoint_name)
+
     policy = endpoint.delivery_policy
     if policy is None:
         policy = EndpointPropertiesUpdateParametersDeliveryPolicy(
             description='delivery_policy',
             rules=[])
 
+    _convert_to_unified_delivery_rules(policy)
+
     conditions = []
     condition = create_condition(match_variable, operator, match_values, selector, negate_condition, transform)
     if condition is not None:
@@ -301,7 +396,8 @@ def add_rule(client, resource_group_name, profile_name, endpoint_name,
     action = create_action(action_name, cache_behavior, cache_duration, header_action, header_name,
                            header_value, query_string_behavior, query_parameters, redirect_type,
                            redirect_protocol, custom_hostname, custom_path, custom_querystring,
-                           custom_fragment, source_pattern, destination, preserve_unmatched_path)
+                           custom_fragment, source_pattern, destination, preserve_unmatched_path,
+                           cmd, resource_group_name, profile_name, endpoint_name, origin_group)
     if action is not None:
         actions.append(action)
 
@@ -317,7 +413,7 @@ def add_rule(client, resource_group_name, profile_name, endpoint_name,
         delivery_policy=policy
     )
 
-    return client.endpoints.update(resource_group_name, profile_name, endpoint_name, params)
+    return client.endpoints.begin_update(resource_group_name, profile_name, endpoint_name, params)
 
 
 def add_condition(client, resource_group_name, profile_name, endpoint_name,
@@ -335,22 +431,23 @@ def add_condition(client, resource_group_name, profile_name, endpoint_name,
         delivery_policy=policy
     )
 
-    return client.endpoints.update(resource_group_name, profile_name, endpoint_name, params)
+    return client.endpoints.begin_update(resource_group_name, profile_name, endpoint_name, params)
 
 
-def add_action(client, resource_group_name, profile_name, endpoint_name,
+def add_action(cmd, client, resource_group_name, profile_name, endpoint_name,
                rule_name, action_name, cache_behavior=None, cache_duration=None,
                header_action=None, header_name=None, header_value=None, query_string_behavior=None,
                query_parameters=None, redirect_type=None, redirect_protocol=None, custom_hostname=None,
                custom_path=None, custom_querystring=None, custom_fragment=None, source_pattern=None,
-               destination=None, preserve_unmatched_path=None):
+               destination=None, preserve_unmatched_path=None, origin_group=None):
 
     endpoint = client.endpoints.get(resource_group_name, profile_name, endpoint_name)
     policy = endpoint.delivery_policy
     action = create_action(action_name, cache_behavior, cache_duration, header_action, header_name,
                            header_value, query_string_behavior, query_parameters, redirect_type,
                            redirect_protocol, custom_hostname, custom_path, custom_querystring,
-                           custom_fragment, source_pattern, destination, preserve_unmatched_path)
+                           custom_fragment, source_pattern, destination, preserve_unmatched_path,
+                           cmd, resource_group_name, profile_name, endpoint_name, origin_group)
     for i in range(0, len(policy.rules)):
         if policy.rules[i].name == rule_name:
             policy.rules[i].actions.append(action)
@@ -359,17 +456,39 @@ def add_action(client, resource_group_name, profile_name, endpoint_name,
         delivery_policy=policy
     )
 
-    return client.endpoints.update(resource_group_name, profile_name, endpoint_name, params)
+    return client.endpoints.begin_update(resource_group_name, profile_name, endpoint_name, params)
 
 
-def remove_rule(client, resource_group_name, profile_name, endpoint_name, rule_name):
+def remove_rule(client, resource_group_name, profile_name, endpoint_name, rule_name=None, order: int = None):
+
+    if rule_name is None and order is None:
+        raise CLIError("Either --rule-name or --order must be specified")
+
+    if order is not None and order < 0:
+        raise CLIError("Order should be non-negative.")
 
     endpoint = client.endpoints.get(resource_group_name, profile_name, endpoint_name)
     policy = endpoint.delivery_policy
     if policy is not None:
-        for rule in policy.rules:
-            if rule.name == rule_name:
-                policy.rules.remove(rule)
+        _convert_to_unified_delivery_rules(policy)
+        pop_index = -1
+        for idx, rule in enumerate(policy.rules):
+            if rule_name is not None and rule.name == rule_name:
+                pop_index = idx
+                break
+            if order is not None and rule.order == order:
+                pop_index = idx
+                break
+
+        # To guarantee the consecutive rule order, we need to make sure the rule with order larger than the deleted one
+        # to decrease its order by one. Rule with order 0 is special and no rule order adjustment is required.
+        if pop_index != -1:
+            pop_order = policy.rules[pop_index].order
+            policy.rules.pop(pop_index)
+            for rule in policy.rules:
+                if rule.order > pop_order and pop_order != 0:
+                    rule.order -= 1
+
     else:
         logger.warning("rule cannot be found. This command will be skipped. Please check the rule name")
 
@@ -377,7 +496,7 @@ def remove_rule(client, resource_group_name, profile_name, endpoint_name, rule_n
         delivery_policy=policy
     )
 
-    return client.endpoints.update(resource_group_name, profile_name, endpoint_name, params)
+    return client.endpoints.begin_update(resource_group_name, profile_name, endpoint_name, params)
 
 
 def remove_condition(client, resource_group_name, profile_name, endpoint_name, rule_name, index):
@@ -395,7 +514,7 @@ def remove_condition(client, resource_group_name, profile_name, endpoint_name, r
         delivery_policy=policy
     )
 
-    return client.endpoints.update(resource_group_name, profile_name, endpoint_name, params)
+    return client.endpoints.begin_update(resource_group_name, profile_name, endpoint_name, params)
 
 
 def remove_action(client, resource_group_name, profile_name, endpoint_name, rule_name, index):
@@ -413,7 +532,7 @@ def remove_action(client, resource_group_name, profile_name, endpoint_name, rule
         delivery_policy=policy
     )
 
-    return client.endpoints.update(resource_group_name, profile_name, endpoint_name, params)
+    return client.endpoints.begin_update(resource_group_name, profile_name, endpoint_name, params)
 
 
 def create_endpoint(client, resource_group_name, profile_name, name, origins, location=None,
@@ -437,20 +556,37 @@ def create_endpoint(client, resource_group_name, profile_name, name, origins, lo
     if is_compression_enabled and not endpoint.content_types_to_compress:
         endpoint.content_types_to_compress = default_content_types()
 
-    return sdk_no_wait(no_wait, client.endpoints.create, resource_group_name, profile_name, name, endpoint)
+    return sdk_no_wait(no_wait, client.endpoints.begin_create, resource_group_name, profile_name, name, endpoint)
+
+
+def purge_endpoint_content(client, resource_group_name, profile_name, endpoint_name,
+                           content_paths, no_wait=None):
+    purge_paramters = PurgeParameters(content_paths=content_paths)
+
+    return sdk_no_wait(no_wait, client.endpoints.begin_purge_content, resource_group_name,
+                       profile_name, endpoint_name, purge_paramters)
+
+
+def load_endpoint_content(client, resource_group_name, profile_name, endpoint_name,
+                          content_paths, no_wait=None):
+    load_paramters = LoadParameters(content_paths=content_paths)
+
+    return sdk_no_wait(no_wait, client.endpoints.begin_load_content, resource_group_name, profile_name,
+                       endpoint_name, load_paramters)
 
 
 # pylint: disable=unused-argument
 def create_custom_domain(client, resource_group_name, profile_name, endpoint_name, custom_domain_name,
                          hostname, location=None, tags=None):
-    return client.custom_domains.create(resource_group_name,
-                                        profile_name,
-                                        endpoint_name,
-                                        custom_domain_name,
-                                        hostname)
+
+    return client.custom_domains.begin_create(resource_group_name,
+                                              profile_name,
+                                              endpoint_name,
+                                              custom_domain_name,
+                                              CustomDomainParameters(host_name=hostname))
 
 
-def enable_custom_https(client, resource_group_name, profile_name, endpoint_name,
+def enable_custom_https(cmd, client, resource_group_name, profile_name, endpoint_name,
                         custom_domain_name, user_cert_subscription_id=None, user_cert_group_name=None,
                         user_cert_vault_name=None, user_cert_secret_name=None, user_cert_secret_version=None,
                         user_cert_protocol_type=None, min_tls_version=None):
@@ -461,7 +597,9 @@ def enable_custom_https(client, resource_group_name, profile_name, endpoint_name
                                        KeyVaultCertificateSourceParameters,
                                        CertificateType,
                                        Profile,
-                                       ProtocolType)
+                                       ProtocolType,
+                                       UpdateRule,
+                                       DeleteRule)
 
     profile: Profile = client.profiles.get(resource_group_name, profile_name)
 
@@ -489,7 +627,7 @@ def enable_custom_https(client, resource_group_name, profile_name, endpoint_name
                            "and --user-cert-protocol-type are all required for user managed certificates.")
 
         if user_cert_subscription_id is None:
-            user_cert_subscription_id = client.config.subscription_id
+            user_cert_subscription_id = get_subscription_id(cmd.cli_ctx)
 
         # All BYOC params are set, let's create the https parameters
         if user_cert_protocol_type is None or user_cert_protocol_type.lower() == 'sni':
@@ -503,7 +641,9 @@ def enable_custom_https(client, resource_group_name, profile_name, endpoint_name
                                                                  resource_group_name=user_cert_group_name,
                                                                  vault_name=user_cert_vault_name,
                                                                  secret_name=user_cert_secret_name,
-                                                                 secret_version=user_cert_secret_version)
+                                                                 secret_version=user_cert_secret_version,
+                                                                 update_rule=UpdateRule.NO_ACTION,
+                                                                 delete_rule=DeleteRule.NO_ACTION)
 
         https_params = UserManagedHttpsParameters(protocol_type=user_cert_protocol_type,
                                                   certificate_source_parameters=cert_source_params,
@@ -563,21 +703,21 @@ def update_origin(client: OriginsOperations,
                   private_link_approval_message: Optional[str] = None):
     from azure.mgmt.cdn.models import OriginUpdateParameters
 
-    return client.update(resource_group_name,
-                         profile_name,
-                         endpoint_name,
-                         origin_name,
-                         OriginUpdateParameters(
-                             host_name=host_name,
-                             http_port=http_port,
-                             https_port=https_port,
-                             enabled=not disabled,
-                             origin_host_header=origin_host_header,
-                             priority=priority,
-                             weight=weight,
-                             private_link_resource_id=private_link_resource_id,
-                             private_link_location=private_link_location,
-                             private_link_approval_message=private_link_approval_message))
+    return client.begin_update(resource_group_name,
+                               profile_name,
+                               endpoint_name,
+                               origin_name,
+                               OriginUpdateParameters(
+                                   host_name=host_name,
+                                   http_port=http_port,
+                                   https_port=https_port,
+                                   enabled=not disabled,
+                                   origin_host_header=origin_host_header,
+                                   priority=priority,
+                                   weight=weight,
+                                   private_link_resource_id=private_link_resource_id,
+                                   private_link_location=private_link_location,
+                                   private_link_approval_message=private_link_approval_message))
 
 
 def create_origin(client: OriginsOperations,
@@ -597,24 +737,28 @@ def create_origin(client: OriginsOperations,
                   private_link_approval_message: Optional[str] = None):
     from azure.mgmt.cdn.models import Origin
 
-    return client.create(resource_group_name,
-                         profile_name,
-                         endpoint_name,
-                         origin_name,
-                         Origin(
-                             host_name=host_name,
-                             http_port=http_port,
-                             https_port=https_port,
-                             enabled=not disabled,
-                             origin_host_header=origin_host_header,
-                             priority=priority,
-                             weight=weight,
-                             private_link_resource_id=private_link_resource_id,
-                             private_link_location=private_link_location,
-                             private_link_approval_message=private_link_approval_message))
+    return client.begin_create(resource_group_name,
+                               profile_name,
+                               endpoint_name,
+                               origin_name,
+                               Origin(
+                                   host_name=host_name,
+                                   http_port=http_port,
+                                   https_port=https_port,
+                                   enabled=not disabled,
+                                   origin_host_header=origin_host_header,
+                                   priority=priority,
+                                   weight=weight,
+                                   private_link_resource_id=private_link_resource_id,
+                                   private_link_location=private_link_location,
+                                   private_link_approval_message=private_link_approval_message))
 
 
 def update_profile(instance, tags=None):
+    if instance.sku.name in (SkuName.premium_azure_front_door, SkuName.standard_azure_front_door):
+        logger.warning('Standard_AzureFrontDoor and Premium_AzureFrontDoor are only supported for AFD profiles')
+        raise ResourceNotFoundError("Operation returned an invalid status code 'Not Found'")
+
     params = ProfileUpdateParameters(tags=tags)
     _update_mapper(instance, params, ['tags'])
     return params
@@ -625,7 +769,7 @@ def create_profile(client, resource_group_name, name,
                    location=None, tags=None):
     from azure.mgmt.cdn.models import (Profile, Sku)
     profile = Profile(location=location, sku=Sku(name=sku), tags=tags)
-    return client.profiles.create(resource_group_name, name, profile)
+    return client.profiles.begin_create(resource_group_name, name, profile)
 
 
 def _parse_ranges(ranges: str):
@@ -650,7 +794,8 @@ def _parse_ranges(ranges: str):
     return [parse_range(error_range) for error_range in ranges.split(',')]
 
 
-def create_origin_group(client: OriginGroupsOperations,
+def create_origin_group(cmd,
+                        client: OriginGroupsOperations,
                         resource_group_name: str,
                         profile_name: str,
                         endpoint_name: str,
@@ -668,12 +813,11 @@ def create_origin_group(client: OriginGroupsOperations,
 
     from azure.mgmt.cdn.models import (OriginGroup,
                                        HealthProbeParameters,
-                                       ResponseBasedOriginErrorDetectionParameters,
-                                       ResourceReference)
+                                       ResponseBasedOriginErrorDetectionParameters)
 
     health_probe_settings = HealthProbeParameters(probe_path=probe_path,
-                                                  probe_request_type=probe_method,
-                                                  probe_protocol=probe_protocol,
+                                                  probe_request_type=HealthProbeRequestType[probe_method.upper()],
+                                                  probe_protocol=ProbeProtocol[probe_protocol.upper()],
                                                   probe_interval_in_seconds=probe_interval)
 
     error_types = None
@@ -690,11 +834,12 @@ def create_origin_group(client: OriginGroupsOperations,
             http_error_ranges=_parse_ranges(response_error_detection_status_code_ranges))
 
     formatted_origins = []
+    subscription_id = get_subscription_id(cmd.cli_ctx)
     if origins:
         for origin in origins.split(','):
             # If the origin is not an ID, assume it's a name and format it as an ID.
             if '/' not in origin:
-                origin = f'/subscriptions/{client.config.subscription_id}/resourceGroups/{resource_group_name}' \
+                origin = f'/subscriptions/{subscription_id}/resourceGroups/{resource_group_name}' \
                          f'/providers/Microsoft.Cdn/profiles/{profile_name}/endpoints/{endpoint_name}' \
                          f'/origins/{origin}'
             formatted_origins.append(ResourceReference(id=origin))
@@ -703,14 +848,15 @@ def create_origin_group(client: OriginGroupsOperations,
                                health_probe_settings=health_probe_settings,
                                response_based_origin_error_detection_settings=error_detection_settings)
 
-    return client.create(resource_group_name,
-                         profile_name,
-                         endpoint_name,
-                         name,
-                         origin_group).result()
+    return client.begin_create(resource_group_name,
+                               profile_name,
+                               endpoint_name,
+                               name,
+                               origin_group).result()
 
 
-def update_origin_group(client: OriginGroupsOperations,
+def update_origin_group(cmd,
+                        client: OriginGroupsOperations,
                         resource_group_name: str,
                         profile_name: str,
                         endpoint_name: str,
@@ -728,8 +874,13 @@ def update_origin_group(client: OriginGroupsOperations,
 
     from azure.mgmt.cdn.models import (OriginGroupUpdateParameters,
                                        HealthProbeParameters,
-                                       ResponseBasedOriginErrorDetectionParameters,
-                                       ResourceReference)
+                                       ResponseBasedOriginErrorDetectionParameters)
+
+    if probe_method is not None:
+        probe_method = HealthProbeRequestType[probe_method.upper()]
+
+    if probe_protocol is not None:
+        probe_protocol = ProbeProtocol[probe_protocol.upper()]
 
     # Get existing health probe settings:
     existing = client.get(resource_group_name,
@@ -776,10 +927,11 @@ def update_origin_group(client: OriginGroupsOperations,
             http_error_ranges=status_code_ranges)
 
     formatted_origins = []
+    subscription_id = get_subscription_id(cmd.cli_ctx)
     for origin in origins.split(','):
         # If the origin is not an ID, assume it's a name and format it as an ID.
         if '/' not in origin:
-            origin = f'/subscriptions/{client.config.subscription_id}/resourceGroups/{resource_group_name}' \
+            origin = f'/subscriptions/{subscription_id}/resourceGroups/{resource_group_name}' \
                      f'/providers/Microsoft.Cdn/profiles/{profile_name}/endpoints/{endpoint_name}' \
                      f'/origins/{origin}'
         formatted_origins.append(ResourceReference(id=origin))
@@ -789,11 +941,11 @@ def update_origin_group(client: OriginGroupsOperations,
         health_probe_settings=health_probe_settings,
         response_based_origin_error_detection_settings=error_detection_settings)
 
-    # client.create isn't really a create, it's a PUT which is create or update,
-    # client.update doesn't allow unsetting fields.
-    return client.create(resource_group_name,
-                         profile_name,
-                         endpoint_name,
-                         name,
-                         origin_group)
+    # client.begin_create isn't really a create, it's a PUT which is create or update,
+    # client.begin_update doesn't allow unsetting fields.
+    return client.begin_create(resource_group_name,
+                               profile_name,
+                               endpoint_name,
+                               name,
+                               origin_group)
 # endregion
