@@ -7,20 +7,20 @@
 from azure.cli.testsdk import ScenarioTest, ResourceGroupPreparer
 
 from azure.cli.command_modules.iot.tests.latest._test_utils import _create_test_cert, _delete_test_cert, _create_verification_cert
+from azure.cli.command_modules.iot.tests.latest.recording_processors import KeyReplacer
 import random
 
 
 class IoTDpsTest(ScenarioTest):
 
+    def __init__(self, method_name):
+        super(IoTDpsTest, self).__init__(
+            method_name, recording_processors=[KeyReplacer()]
+        )
+
     @ResourceGroupPreparer(parameter_name='group_name', parameter_name_for_location='group_location')
     def test_dps_lifecycle(self, group_name, group_location):
         dps_name = self.create_random_name('dps', 20)
-        hub_name = self.create_random_name('iot', 20)
-
-        self.cmd('iot hub create -n {} -g {} --sku S1'.format(hub_name, group_name),
-                 checks=[self.check('resourcegroup', group_name),
-                         self.check('name', hub_name),
-                         self.check('sku.name', 'S1')])
 
         # Create DPS
         tags = "key1=value1 key2=value2"
@@ -65,33 +65,46 @@ class IoTDpsTest(ScenarioTest):
         new_right = 'EnrollmentWrite'
 
         # Create access policy
-        self.cmd('az iot dps access-policy create -g {} --dps-name {} -n {} -r {}'.format(group_name, dps_name, policy_name, right), checks=[
+        self.cmd('az iot dps policy create -g {} --dps-name {} --pn {} -r {}'.format(group_name, dps_name, policy_name, right), checks=[
             self.check('keyName', policy_name),
             self.check('rights', right)
         ])
 
         # List access policy
-        self.cmd('az iot dps access-policy list -g {} --dps-name {}'.format(group_name, dps_name), checks=[
+        self.cmd('az iot dps policy list -g {} --dps-name {}'.format(group_name, dps_name), checks=[
             self.check('length([*])', 2),
             self.check('[1].keyName', policy_name),
             self.check('[1].rights', right)
         ])
 
         # Get access policy
-        self.cmd('az iot dps access-policy show -g {} --dps-name {} -n {}'.format(group_name, dps_name, policy_name), checks=[
+        self.cmd('az iot dps policy show -g {} --dps-name {} --pn {}'.format(group_name, dps_name, policy_name), checks=[
             self.check('keyName', policy_name),
             self.check('rights', right)
         ])
 
         # Create update policy
-        self.cmd('az iot dps access-policy update -g {} --dps-name {} -n {} -r {}'.format(group_name, dps_name, policy_name, new_right),
+        self.cmd('az iot dps policy update -g {} --dps-name {} --pn {} -r {}'.format(group_name, dps_name, policy_name, new_right),
                  checks=[
                      self.check('keyName', policy_name),
                      self.check('rights', new_right)
         ])
 
         # Delete policy
-        self.cmd('az iot dps access-policy delete -g {} --dps-name {} -n {}'.format(group_name, dps_name, policy_name))
+        self.cmd('az iot dps policy delete -g {} --dps-name {} --pn {}'.format(group_name, dps_name, policy_name))
+
+        # Delete DPS
+        self.cmd('az iot dps delete -g {} -n {}'.format(group_name, dps_name))
+
+
+    @ResourceGroupPreparer(parameter_name='group_name', parameter_name_for_location='group_location')
+    def test_dps_certificate_lifecycle(self, group_name, group_location):
+        dps_name = self.create_random_name('dps', 20)
+
+        # Create DPS
+        self.cmd('az iot dps create -g {} -n {}'.format(group_name, dps_name),
+                 checks=[self.check('name', dps_name),
+                         self.check('location', group_location)])
 
         # Test DPS Certificate Lifecycle
         cert_name = self.create_random_name('certificate', 20)
@@ -118,13 +131,14 @@ class IoTDpsTest(ScenarioTest):
         ]).get_output_in_json()['etag']
 
         # List certificates
-        self.cmd('az iot dps certificate list --dps-name {} -g {}'.format(dps_name, group_name),
-                 checks=[
-                     self.check('length(value)', 2),
-                     self.check('value[0].name', cert_name_verified),
-                     self.check('value[0].properties.isVerified', True),
-                     self.check('value[1].name', cert_name),
-                     self.check('value[1].properties.isVerified', False)])
+        cert_list = self.cmd('az iot dps certificate list --dps-name {} -g {}'.format(dps_name, group_name),
+                             checks=[self.check('length(value)', 2)]
+                            ).get_output_in_json()['value']
+
+        for cert in cert_list:
+            assert cert['name'] == cert_name_verified if cert['properties']['isVerified'] else cert_name
+
+        assert cert_list[0]['name'] != cert_list[1]['name']
 
         # Get certificate
         etag = self.cmd('az iot dps certificate show --dps-name {} -g {} --name {}'.format(dps_name, group_name, cert_name), checks=[
@@ -165,17 +179,63 @@ class IoTDpsTest(ScenarioTest):
 
         _delete_test_cert(cert_file, key_file, verification_file)
 
-        # Test DPS Linked Hub Lifecycle
+        # Delete DPS
+        self.cmd('az iot dps delete -g {} -n {}'.format(group_name, dps_name))
+
+
+    @ResourceGroupPreparer(parameter_name='group_name', parameter_name_for_location='group_location')
+    def test_dps_linked_hub_lifecycle(self, group_name, group_location):
+        dps_name = self.create_random_name('dps', 20)
+        hub_name = self.create_random_name('iot', 20)
+        hub_host_name = '{}.azure-devices.net'.format(hub_name)
         key_name = self.create_random_name('key', 20)
         permission = 'RegistryWrite'
 
-        # Set up a hub with a policy to be link
-        hub_host_name = '{}.azure-devices.net'.format(hub_name)
+        # Create DPS
+        self.cmd('az iot dps create -g {} -n {}'.format(group_name, dps_name),
+                 checks=[self.check('name', dps_name),
+                         self.check('location', group_location)])
+
+        # Create and set up Hub
+        self.cmd('az iot hub create -n {} -g {} --sku S1'.format(hub_name, group_name),
+                 checks=[self.check('resourcegroup', group_name),
+                         self.check('name', hub_name),
+                         self.check('sku.name', 'S1')])
 
         self.cmd('az iot hub policy create --hub-name {} -n {} --permissions {}'.format(hub_name, key_name, permission))
 
-        connection_string = self._show_hub_connection_string(hub_name, group_name)
+        # Create linked-hub fails if there is no hub name or connection string
+        self.cmd('az iot dps linked-hub create --dps-name {} -g {} --l {}'
+                 .format(dps_name, group_name, group_location),
+                 expect_failure=True)
 
+        # Create linked-hub fails with a fake connection string
+        self.cmd('az iot dps linked-hub create --dps-name {} -g {} --connection-string {}'
+                 .format(dps_name, group_name, "Test"),
+                 expect_failure=True)
+
+        # Create linked-hub with only hub name
+        self.cmd('az iot dps linked-hub create --dps-name {} -g {} --hub-name {}'
+                 .format(dps_name, group_name, hub_name))
+        self.cmd('az iot dps linked-hub delete --dps-name {} -g {} --linked-hub {}'.format(dps_name, group_name, hub_host_name))
+
+        # Create linked-hub with hub name, resource group, location
+        self.cmd('az iot dps linked-hub create --dps-name {} -g {} --hub-name {} --hrg {} --l {}'
+                 .format(dps_name, group_name, hub_name, group_name, group_location))
+        self.cmd('az iot dps linked-hub delete --dps-name {} -g {} --linked-hub {}'.format(dps_name, group_name, hub_name))
+
+        # Create linked-hub using only connection string
+        connection_string = self._show_hub_connection_string(hub_name, group_name)
+        self.cmd('az iot dps linked-hub create --dps-name {} -g {} --connection-string {}'
+                 .format(dps_name, group_name, connection_string))
+        self.cmd('az iot dps linked-hub delete --dps-name {} -g {} --linked-hub {}'.format(dps_name, group_name, hub_name))
+
+        # Create linked-hub using only connection string in lower case
+        self.cmd('az iot dps linked-hub create --dps-name {} -g {} --connection-string {}'
+                 .format(dps_name, group_name, connection_string.lower()))
+        self.cmd('az iot dps linked-hub delete --dps-name {} -g {} --linked-hub {}'.format(dps_name, group_name, hub_name))
+
+        # Create linked-hub using connection string and location
         self.cmd('az iot dps linked-hub create --dps-name {} -g {} --connection-string {} -l {}'
                  .format(dps_name, group_name, connection_string, group_location))
 
@@ -190,6 +250,12 @@ class IoTDpsTest(ScenarioTest):
             self.check('location', group_location)
         ])
 
+        # Linked hub should support host name and hub name
+        self.cmd('az iot dps linked-hub show --dps-name {} -g {} --linked-hub {}'.format(dps_name, group_name, hub_name), checks=[
+            self.check('name', hub_host_name),
+            self.check('location', group_location)
+        ])
+
         allocationWeight = 10
         applyAllocationPolicy = True
         self.cmd('az iot dps linked-hub update --dps-name {} -g {} --linked-hub {} --allocation-weight {} --apply-allocation-policy {}'
@@ -204,8 +270,9 @@ class IoTDpsTest(ScenarioTest):
 
         self.cmd('az iot dps linked-hub delete --dps-name {} -g {} --linked-hub {}'.format(dps_name, group_name, hub_host_name))
 
-        # Delete DPS
+        # Delete DPS and Hub
         self.cmd('az iot dps delete -g {} -n {}'.format(group_name, dps_name))
+        self.cmd('az iot hub delete -n {} -g {}'.format(hub_name, group_name))
 
     def _get_hub_policy_primary_key(self, hub_name, key_name):
         output = self.cmd('az iot hub policy show --hub-name {} -n {}'.format(hub_name, key_name))
