@@ -88,12 +88,6 @@ def get_docs_tmpl(cli_ctx, resource_type, client_name, module_name='operations')
         obj_name='{}')
 
 
-def get_client_api_version(cli_ctx, resource_type):
-    if resource_type == ResourceType.DATA_KEYVAULT_KEYS:
-        return '7.3-preview' if not is_azure_stack_profile(cmd=None, cli_ctx=cli_ctx) else '2016-10-01'
-    return get_api_version(cli_ctx, resource_type)
-
-
 def get_client_factory(resource_type, client_name=''):
     if is_mgmt_plane(resource_type):
         return keyvault_mgmt_client_factory(resource_type, client_name)
@@ -227,12 +221,13 @@ def data_plane_azure_keyvault_key_client(cli_ctx, command_args):
     command_args.pop('hsm_name', None)
     command_args.pop('vault_base_url', None)
     command_args.pop('identifier', None)
+    api_version = '7.3-preview' if not is_azure_stack_profile(cmd=None, cli_ctx=cli_ctx) else '2016-10-01'
     return KeyClient(
-        vault_url=vault_url, credential=credential, api_version=version)
+        vault_url=vault_url, credential=credential, api_version=api_version or version)
 
 
 def _prepare_data_plane_azure_keyvault_client(cli_ctx, command_args, resource_type):
-    version = str(get_client_api_version(cli_ctx, resource_type))
+    version = str(get_api_version(cli_ctx, resource_type))
     profile = Profile(cli_ctx=cli_ctx)
     credential, _, _ = profile.get_login_credentials()
     vault_url = \
