@@ -5,7 +5,7 @@
 
 from azure.cli.testsdk import LiveScenarioTest, ScenarioTest, ResourceGroupPreparer, record_only
 from knack.util import CLIError
-from azure_devtools.scenario_tests import AllowLargeResponse
+from azure.cli.testsdk.scenario_tests import AllowLargeResponse
 
 
 class TestMonitorAutoscaleScenario(ScenarioTest):
@@ -237,12 +237,18 @@ class TestMonitorAutoscaleScenario(ScenarioTest):
             self.check('recurrence', None)
         ])
 
+        # test autoscale profile show
+        self.cmd('monitor autoscale profile show -g {rg} --autoscale-name {vmss} -n {sched}', checks=[
+            self.check('name', '{sched}')
+        ])
+
         self.cmd('monitor autoscale profile list -g {rg} --autoscale-name {vmss}',
                  checks=self.check('length(@)', 2))
         self.cmd('monitor autoscale profile delete -g {rg} --autoscale-name {vmss} -n {sched}')
         self.cmd('monitor autoscale profile list -g {rg} --autoscale-name {vmss}',
                  checks=self.check('length(@)', 1))
 
+
     @ResourceGroupPreparer(name_prefix='cli_test_monitor_autoscale_recurring')
     def test_monitor_autoscale_recurring(self, resource_group):
         import json
@@ -317,8 +323,8 @@ class TestMonitorAutoscaleTimezones(LiveScenarioTest):
                  checks=self.check('length(@)', 1))
 
 
-class TestMonitorAutoscaleComplexRules(ScenarioTest):
-    @AllowLargeResponse()
+class TestMonitorAutoscaleComplexRules(LiveScenarioTest):
+
     def setUp(self):
         super(TestMonitorAutoscaleComplexRules, self).setUp()
         self.cmd('extension add -n spring-cloud')
@@ -327,7 +333,6 @@ class TestMonitorAutoscaleComplexRules(ScenarioTest):
         self.cmd('extension remove -n spring-cloud')
         super(TestMonitorAutoscaleComplexRules, self).tearDown()
 
-#    @record_only()
     @AllowLargeResponse()
     @ResourceGroupPreparer(name_prefix='cli_test_monitor_autoscale_rule_for_spring_cloud', location='westus2')
     def test_monitor_autoscale_rule_for_spring_cloud(self, resource_group):
