@@ -1056,11 +1056,14 @@ def process_tm_endpoint_create_namespace(cmd, namespace):
 
     routing_type = profile.traffic_routing_method  # pylint: disable=no-member
     endpoint_type = namespace.endpoint_type
-    all_options = ['target_resource_id', 'target', 'min_child_endpoints', 'priority', 'weight', 'endpoint_location']
+    all_options = ['target_resource_id', 'target', 'min_child_endpoints',
+                   'min_child_ipv4', 'min_child_ipv6', 'priority', 'weight', 'endpoint_location']
     props_to_options = {
         'target_resource_id': '--target-resource-id',
         'target': '--target',
         'min_child_endpoints': '--min-child-endpoints',
+        'min_child_ipv4': '--min-child-ipv4',
+        'min_child_ipv6': '--min-child-ipv6',
         'priority': '--priority',
         'weight': '--weight',
         'endpoint_location': '--endpoint-location',
