@@ -36,6 +36,7 @@ def register_providers():
     _register_one_provider('Microsoft.EventGrid/domains', '2020-04-01-preview', True)
     _register_one_provider("Microsoft.EventHub/namespaces", "2021-06-01-preview", True)
     _register_one_provider("Microsoft.HDInsight/clusters", '2018-06-01-preview', True)
+    _register_one_provider("Microsoft.HybridCompute/privateLinkScopes", '2021-05-20', True)
     _register_one_provider("Microsoft.HealthcareApis/services", "2020-03-30", True)
     _register_one_provider('microsoft.insights/privateLinkScopes', '2019-10-17-preview', True)
     _register_one_provider('Microsoft.KeyVault/managedHSMs', '2021-04-01-preview', True)
@@ -59,6 +60,8 @@ def register_providers():
     _register_one_provider('Microsoft.Web/sites', '2019-08-01', False)
     _register_one_provider("Microsoft.Web/hostingEnvironments", "2020-10-01", True)
     _register_one_provider('Microsoft.SignalRService/WebPubSub', '2021-09-01-preview', False)
+    _register_one_provider('Microsoft.DataFactory/factories', '2018-06-01', True)
+    _register_one_provider('Microsoft.Databricks/workspaces', '2021-04-01-preview', True)
 
 
 def _register_one_provider(provider, api_version, support_list_or_not, resource_get_api_version=None, support_connection_operation=True):  # pylint: disable=line-too-long
