@@ -16,7 +16,7 @@ def cli_namespace_create(client, resource_group_name, namespace_name, location=N
                          capacity=None, default_action=None):
 
     from azure.mgmt.servicebus.models import SBNamespace, SBSku
-    client.create_or_update(
+    client.begin_create_or_update(
         resource_group_name=resource_group_name,
         namespace_name=namespace_name,
         parameters=SBNamespace(
@@ -66,14 +66,19 @@ def cli_namespace_list(client, resource_group_name=None):
     return client.list()
 
 
+def cli_namespace_exists(client, name):
+
+    return client.check_name_availability(parameters={'name': name})
+
+
 # Namespace Authorization rule:
-def cli_namespaceautho_create(client, resource_group_name, namespace_name, name, access_rights=None):
+def cli_namespaceautho_create(client, resource_group_name, namespace_name, name, rights=None):
     from azure.cli.command_modules.servicebus._utils import accessrights_converter
     return client.create_or_update_authorization_rule(
         resource_group_name=resource_group_name,
         namespace_name=namespace_name,
         authorization_rule_name=name,
-        rights=accessrights_converter(access_rights)
+        parameters={'rights': accessrights_converter(rights)}
     )
 
 
@@ -84,6 +89,15 @@ def cli_namespaceautho_update(instance, rights):
     return instance
 
 
+def cli_keys_renew(client, resource_group_name, namespace_name, name, key_type):
+    return client.regenerate_keys(
+        resource_group_name=resource_group_name,
+        namespace_name=namespace_name,
+        authorization_rule_name=name,
+        parameters={'key_type': key_type}
+    )
+
+
 # Queue Region
 def cli_sbqueue_create(cmd, client, resource_group_name, namespace_name, queue_name, lock_duration=None,
                        max_size_in_megabytes=None, requires_duplicate_detection=None, requires_session=None,
@@ -172,6 +186,29 @@ def cli_sbqueue_update(instance, lock_duration=None,
     return instance
 
 
+# Queue Authorization rule:
+def cli_queueautho_create(client, resource_group_name, namespace_name, queue_name, name, rights=None):
+    from azure.cli.command_modules.servicebus._utils import accessrights_converter
+    return client.create_or_update_authorization_rule(
+        resource_group_name=resource_group_name,
+        namespace_name=namespace_name,
+        queue_name=queue_name,
+        authorization_rule_name=name,
+        parameters={'rights': accessrights_converter(rights)}
+    )
+
+
+def cli_queueauthokey_renew(client, resource_group_name, namespace_name, queue_name, name, key_type=None, key=None):
+
+    return client.regenerate_keys(
+        resource_group_name=resource_group_name,
+        namespace_name=namespace_name,
+        queue_name=queue_name,
+        authorization_rule_name=name,
+        parameters={'key_type': key_type, 'key': key}
+    )
+
+
 # Topic Region
 def cli_sbtopic_create(cmd, client, resource_group_name, namespace_name, topic_name, default_message_time_to_live=None,
                        max_size_in_megabytes=None, requires_duplicate_detection=None,
@@ -238,6 +275,29 @@ def cli_sbtopic_update(instance, default_message_time_to_live=None,
     return instance
 
 
+# Topic Authorization rule
+def cli_topicautho_create(client, resource_group_name, namespace_name, topic_name, name, rights=None):
+    from azure.cli.command_modules.servicebus._utils import accessrights_converter
+    return client.create_or_update_authorization_rule(
+        resource_group_name=resource_group_name,
+        namespace_name=namespace_name,
+        topic_name=topic_name,
+        authorization_rule_name=name,
+        parameters={'rights': accessrights_converter(rights)}
+    )
+
+
+def cli_topicauthokey_renew(client, resource_group_name, namespace_name, topic_name, name, key_type=None, key=None):
+
+    return client.regenerate_keys(
+        resource_group_name=resource_group_name,
+        namespace_name=namespace_name,
+        topic_name=topic_name,
+        authorization_rule_name=name,
+        parameters={'key_type': key_type, 'key': key}
+    )
+
+
 # Subscription Region
 def cli_sbsubscription_create(client, resource_group_name, namespace_name, topic_name, subscription_name, lock_duration=None,
                               requires_session=None, default_message_time_to_live=None, dead_lettering_on_message_expiration=None,
@@ -396,23 +456,57 @@ def cli_rules_update(instance,
     return instance
 
 
-def cli_migration_start(client, resource_group_name, namespace_name, target_namespace, post_migration_name):
-    import time
+# DisasterRecoveryConfigs Region
+def cli_georecovery_alias_create(client, resource_group_name, namespace_name, alias,
+                                 partner_namespace, alternate_name=None):
 
-    client.create_and_start_migration(resource_group_name, namespace_name, target_namespace, post_migration_name)
-    getresponse = client.get(resource_group_name, namespace_name)
+    parameters = {
+        'partner_namespace': partner_namespace,
+        'alternate_name': alternate_name,
+    }
+    return client.create_or_update(resource_group_name=resource_group_name, namespace_name=namespace_name,
+                                   alias=alias, parameters=parameters)
+
+
+def cli_georecovery_alias_exists(client, resource_group_name, namespace_name, name):
+
+    return client.check_name_availability(resource_group_name=resource_group_name,
+                                          namespace_name=namespace_name,
+                                          parameters={'name': name})
+
+
+# MigrationConfigs Region
+def cli_migration_start(client, resource_group_name, namespace_name,
+                        target_namespace, post_migration_name, config_name="$default"):
+    import time
+    parameters = {
+        'target_namespace': target_namespace,
+        'post_migration_name': post_migration_name
+    }
+    client.begin_create_and_start_migration(resource_group_name, namespace_name, config_name, parameters)
+    getresponse = client.get(resource_group_name, namespace_name, config_name)
 
     # pool till Provisioning state is succeeded
     while getresponse.provisioning_state != 'Succeeded':
         time.sleep(30)
-        getresponse = client.get(resource_group_name, namespace_name)
+        getresponse = client.get(resource_group_name, namespace_name, config_name)
 
     # poll on the 'pendingReplicationOperationsCount' to be 0 or none
     while getresponse.pending_replication_operations_count != 0 and getresponse.pending_replication_operations_count is not None:
         time.sleep(30)
-        getresponse = client.get(resource_group_name, namespace_name)
+        getresponse = client.get(resource_group_name, namespace_name, config_name)
 
-    return client.get(resource_group_name, namespace_name)
+    return client.get(resource_group_name, namespace_name, config_name)
+
+
+def cli_migration_show(client, resource_group_name, namespace_name, config_name="$default"):
+
+    return client.get(resource_group_name, namespace_name, config_name)
+
+
+def cli_migration_complete(client, resource_group_name, namespace_name, config_name="$default"):
+
+    return client.complete_migration(resource_group_name, namespace_name, config_name)
 
 
 iso8601pattern = re.compile("^P(?!$)(\\d+Y)?(\\d+M)?(\\d+W)?(\\d+D)?(T(?=\\d)(\\d+H)?(\\d+M)?(\\d+.)?(\\d+S)?)?$")
