@@ -7,7 +7,7 @@ from azure.cli.testsdk import (ScenarioTest, JMESPathCheck, ResourceGroupPrepare
 from azure.cli.core.profiles import ResourceType
 from ..storage_test_util import StorageScenarioMixin
 from knack.util import CLIError
-from azure_devtools.scenario_tests import AllowLargeResponse
+from azure.cli.testsdk.scenario_tests import AllowLargeResponse
 
 
 @api_version_constraint(ResourceType.MGMT_STORAGE, min_api='2016-12-01')
@@ -22,7 +22,7 @@ class StorageAccountTests(StorageScenarioMixin, ScenarioTest):
             'vnet': 'vnet1',
             'subnet': 'subnet1'
         }
-        self.cmd('storage account create -g {rg} -n {acc} --sku Standard_LRS --bypass Metrics --default-action Deny --https-only '
+        self.cmd('storage account create -g {rg} -n {acc} --bypass Metrics --default-action Deny --https-only '
                  .format(**kwargs),
                  checks=[
                      JMESPathCheck('networkRuleSet.bypass', 'Metrics'),
@@ -86,57 +86,73 @@ class StorageAccountTests(StorageScenarioMixin, ScenarioTest):
         self.assertTrue(result['identity']['principalId'])
         self.assertTrue(result['identity']['tenantId'])
 
-    # @AllowLargeResponse()
-    # @ResourceGroupPreparer(parameter_name_for_location='location')
-    # def test_create_storage_account(self, resource_group, location):
-    #     name = self.create_random_name(prefix='cli', length=24)
+    @AllowLargeResponse()
+    @ResourceGroupPreparer(parameter_name_for_location='location')
+    def test_create_storage_account(self, resource_group, location):
+        name = self.create_random_name(prefix='cli', length=24)
 
-    #     self.cmd('az storage account create -n {} -g {} --sku {} -l {} --https-only '.format(
-    #         name, resource_group, 'Standard_LRS', location))
+        self.cmd('az storage account create -n {} -g {} --sku {} -l {} --https-only '.format(
+            name, resource_group, 'Standard_LRS', location))
 
-    #     self.cmd('storage account check-name --name {}'.format(name), checks=[
-    #         JMESPathCheck('nameAvailable', False),
-    #         JMESPathCheck('reason', 'AlreadyExists')
-    #     ])
+        self.cmd('storage account check-name --name {}'.format(name), checks=[
+            JMESPathCheck('nameAvailable', False),
+            JMESPathCheck('reason', 'AlreadyExists')
+        ])
 
-    #     self.cmd('storage account list -g {}'.format(resource_group), checks=[
-    #         JMESPathCheck('[0].location', 'westus'),
-    #         JMESPathCheck('[0].sku.name', 'Standard_LRS'),
-    #         JMESPathCheck('[0].resourceGroup', resource_group)
-    #     ])
+        self.cmd('storage account list -g {}'.format(resource_group), checks=[
+            JMESPathCheck('[0].location', 'westus'),
+            JMESPathCheck('[0].sku.name', 'Standard_LRS'),
+            JMESPathCheck('[0].resourceGroup', resource_group)
+        ])
 
-    #     self.cmd('az storage account show -n {} -g {}'.format(name, resource_group), checks=[
-    #         JMESPathCheck('name', name),
-    #         JMESPathCheck('location', location),
-    #         JMESPathCheck('sku.name', 'Standard_LRS'),
-    #         JMESPathCheck('kind', 'Storage')
-    #     ])
+        self.cmd('az storage account show -n {} -g {}'.format(name, resource_group), checks=[
+            JMESPathCheck('name', name),
+            JMESPathCheck('location', location),
+            JMESPathCheck('sku.name', 'Standard_LRS'),
+            JMESPathCheck('kind', 'Storage')
+        ])
 
-    #     self.cmd('az storage account show -n {}'.format(name), checks=[
-    #         JMESPathCheck('name', name),
-    #         JMESPathCheck('location', location),
-    #         JMESPathCheck('sku.name', 'Standard_LRS'),
-    #         JMESPathCheck('kind', 'Storage')
-    #     ])
+        self.cmd('az storage account show -n {}'.format(name), checks=[
+            JMESPathCheck('name', name),
+            JMESPathCheck('location', location),
+            JMESPathCheck('sku.name', 'Standard_LRS'),
+            JMESPathCheck('kind', 'Storage')
+        ])
 
-    #     self.cmd('storage account show-connection-string -g {} -n {} --protocol http'.format(
-    #         resource_group, name), checks=[
-    #             JMESPathCheck("contains(connectionString, 'https')", False),
-    #             JMESPathCheck("contains(connectionString, '{}')".format(name), True)])
+        self.cmd('storage account show-connection-string -g {} -n {} --protocol http'.format(
+            resource_group, name), checks=[
+                JMESPathCheck("contains(connectionString, 'https')", False),
+                JMESPathCheck("contains(connectionString, '{}')".format(name), True)])
 
-    #     self.cmd('storage account update -g {} -n {} --tags foo=bar cat'
-    #              .format(resource_group, name),
-    #              checks=JMESPathCheck('tags', {'cat': '', 'foo': 'bar'}))
-    #     self.cmd('storage account update -g {} -n {} --sku Standard_GRS --tags'
-    #              .format(resource_group, name),
-    #              checks=[JMESPathCheck('tags', {}),
-    #                      JMESPathCheck('sku.name', 'Standard_GRS')])
-    #     self.cmd('storage account update -g {} -n {} --set tags.test=success'
-    #              .format(resource_group, name),
-    #              checks=JMESPathCheck('tags', {'test': 'success'}))
-    #     self.cmd('storage account delete -g {} -n {} --yes'.format(resource_group, name))
-    #     self.cmd('storage account check-name --name {}'.format(name),
-    #              checks=JMESPathCheck('nameAvailable', True))
+        self.cmd('storage account update -g {} -n {} --tags foo=bar cat'
+                 .format(resource_group, name),
+                 checks=JMESPathCheck('tags', {'cat': '', 'foo': 'bar'}))
+        self.cmd('storage account update -g {} -n {} --sku Standard_GRS --tags'
+                 .format(resource_group, name),
+                 checks=[JMESPathCheck('tags', {}),
+                         JMESPathCheck('sku.name', 'Standard_GRS')])
+        self.cmd('storage account update -g {} -n {} --set tags.test=success'
+                 .format(resource_group, name),
+                 checks=JMESPathCheck('tags', {'test': 'success'}))
+        self.cmd('storage account delete -g {} -n {} --yes'.format(resource_group, name))
+        self.cmd('storage account check-name --name {}'.format(name),
+                 checks=JMESPathCheck('nameAvailable', True))
+
+    @api_version_constraint(ResourceType.MGMT_STORAGE, min_api='2017-10-01')
+    @ResourceGroupPreparer(parameter_name_for_location='location', location='southcentralus')
+    def test_create_storage_account_v2(self, resource_group, location):
+        self.kwargs.update({
+            'name': self.create_random_name(prefix='cli', length=24),
+            'loc': location
+        })
+
+        self.cmd('storage account create -n {name} -g {rg} -l {loc} --kind StorageV2 --https-only ',
+                 checks=[JMESPathCheck('kind', 'StorageV2')])
+
+        self.cmd('storage account check-name --name {name}', checks=[
+            JMESPathCheck('nameAvailable', False),
+            JMESPathCheck('reason', 'AlreadyExists')
+        ])
 
     @api_version_constraint(ResourceType.MGMT_STORAGE, min_api='2017-10-01')
     @ResourceGroupPreparer(location='southcentralus')
@@ -145,28 +161,35 @@ class StorageAccountTests(StorageScenarioMixin, ScenarioTest):
         create_cmd = 'az storage account create -n {} -g {} --https-only '.format(name, resource_group)
         self.cmd(create_cmd, checks=[JMESPathCheck('sku.name', 'Standard_RAGRS')])
 
+    @api_version_constraint(ResourceType.MGMT_STORAGE, min_api='2017-10-01')
+    @ResourceGroupPreparer(location='southcentralus')
+    def test_storage_create_default_kind(self, resource_group):
+        name = self.create_random_name(prefix='cli', length=24)
+        create_cmd = 'az storage account create -n {} -g {} --https-only'.format(name, resource_group)
+        self.cmd(create_cmd, checks=[JMESPathCheck('kind', 'Storage')])
+
     def test_show_usage(self):
-        self.cmd('storage account show-usage -l westus', checks=JMESPathCheck('name.value', 'StorageAccounts'))
+        self.cmd('storage account show-usage', checks=JMESPathCheck('name.value', 'StorageAccounts'))
 
-    # @ResourceGroupPreparer()
-    # @StorageAccountPreparer()
-    # def test_logging_operations(self, resource_group, storage_account):
-    #     connection_string = self.cmd(
-    #         'storage account show-connection-string -g {} -n {} -otsv'.format(resource_group, storage_account)).output
+    @ResourceGroupPreparer()
+    @StorageAccountPreparer()
+    def test_logging_operations(self, resource_group, storage_account):
+        connection_string = self.cmd(
+            'storage account show-connection-string -g {} -n {} -otsv'.format(resource_group, storage_account)).output
 
-    #     self.cmd('storage logging show --connection-string {}'.format(connection_string), checks=[
-    #         JMESPathCheck('blob.read', False),
-    #         JMESPathCheck('blob.retentionPolicy.enabled', False)
-    #     ])
+        self.cmd('storage logging show --connection-string {}'.format(connection_string), checks=[
+            JMESPathCheck('blob.read', False),
+            JMESPathCheck('blob.retentionPolicy.enabled', False)
+        ])
 
-    #     self.cmd('storage logging update --services b --log r --retention 1 '
-    #              '--service b --connection-string {}'.format(connection_string))
+        self.cmd('storage logging update --services b --log r --retention 1 '
+                 '--service b --connection-string {}'.format(connection_string))
 
-    #     self.cmd('storage logging show --connection-string {}'.format(connection_string), checks=[
-    #         JMESPathCheck('blob.read', True),
-    #         JMESPathCheck('blob.retentionPolicy.enabled', True),
-    #         JMESPathCheck('blob.retentionPolicy.days', 1)
-    #     ])
+        self.cmd('storage logging show --connection-string {}'.format(connection_string), checks=[
+            JMESPathCheck('blob.read', True),
+            JMESPathCheck('blob.retentionPolicy.enabled', True),
+            JMESPathCheck('blob.retentionPolicy.days', 1)
+        ])
 
     @ResourceGroupPreparer()
     @StorageAccountPreparer()
@@ -192,37 +215,37 @@ class StorageAccountTests(StorageScenarioMixin, ScenarioTest):
         assert next(acc for acc in accounts_list if acc['name'] == account_1)
         assert next(acc for acc in accounts_list if acc['name'] == account_2)
 
-    # @ResourceGroupPreparer()
-    # @StorageAccountPreparer()
-    # def test_renew_account_key(self, resource_group, storage_account):
-    #     original_keys = self.cmd('storage account keys list -g {} -n {}'
-    #                              .format(resource_group, storage_account)).get_output_in_json()
-    #     # key1 = keys_result[0]
-    #     # key2 = keys_result[1]
-    #     assert original_keys[0] and original_keys[1]
+    @ResourceGroupPreparer()
+    @StorageAccountPreparer()
+    def test_renew_account_key(self, resource_group, storage_account):
+        original_keys = self.cmd('storage account keys list -g {} -n {}'
+                                 .format(resource_group, storage_account)).get_output_in_json()
+        # key1 = keys_result[0]
+        # key2 = keys_result[1]
+        assert original_keys[0] and original_keys[1]
 
-    #     renewed_keys = self.cmd('storage account keys renew -g {} -n {} --key primary'
-    #                             .format(resource_group, storage_account)).get_output_in_json()
-    #     print(renewed_keys)
-    #     print(original_keys)
-    #     assert renewed_keys[0] != original_keys[0]
-    #     assert renewed_keys[1] == original_keys[1]
+        renewed_keys = self.cmd('storage account keys renew -g {} -n {} --key primary'
+                                .format(resource_group, storage_account)).get_output_in_json()
+        print(renewed_keys)
+        print(original_keys)
+        assert renewed_keys[0] != original_keys[0]
+        assert renewed_keys[1] == original_keys[1]
 
-    #     original_keys = renewed_keys
-    #     renewed_keys = self.cmd('storage account keys renew -g {} -n {} --key secondary'
-    #                             .format(resource_group, storage_account)).get_output_in_json()
-    #     assert renewed_keys[0] == original_keys[0]
-    #     assert renewed_keys[1] != original_keys[1]
+        original_keys = renewed_keys
+        renewed_keys = self.cmd('storage account keys renew -g {} -n {} --key secondary'
+                                .format(resource_group, storage_account)).get_output_in_json()
+        assert renewed_keys[0] == original_keys[0]
+        assert renewed_keys[1] != original_keys[1]
 
-    # @AllowLargeResponse()
-    # @ResourceGroupPreparer()
-    # @StorageAccountPreparer()
-    # def test_create_account_sas(self, storage_account):
-    #     sas = self.cmd('storage account generate-sas --resource-types o --services b '
-    #                    '--expiry 2046-12-31T08:23Z --permissions r --https-only --account-name {}'
-    #                    .format(storage_account)).output
-    #     self.assertIn('sig=', sas, 'SAS token {} does not contain sig segment'.format(sas))
-    #     self.assertIn('se=', sas, 'SAS token {} does not contain se segment'.format(sas))
+    @AllowLargeResponse()
+    @ResourceGroupPreparer()
+    @StorageAccountPreparer()
+    def test_create_account_sas(self, storage_account):
+        sas = self.cmd('storage account generate-sas --resource-types o --services b '
+                       '--expiry 2046-12-31T08:23Z --permissions r --https-only --account-name {}'
+                       .format(storage_account)).output
+        self.assertIn('sig=', sas, 'SAS token {} does not contain sig segment'.format(sas))
+        self.assertIn('se=', sas, 'SAS token {} does not contain se segment'.format(sas))
 
     def test_list_locations(self):
         self.cmd('az account list-locations',
