@@ -103,19 +103,31 @@ class StorageBlobQueryTests(StorageScenarioMixin, LiveScenarioTest):
     def test_storage_blob_query_scenario(self, resource_group, storage_account):
         account_info = self.get_account_info(group=resource_group, name=storage_account)
         container = self.create_container(account_info)
-        blob = self.create_random_name(prefix='blob', length=12)
+        csv_blob = self.create_random_name(prefix='csvblob', length=12)
         curr_dir = os.path.dirname(os.path.realpath(__file__))
         csv_file = os.path.join(curr_dir, 'quick_query.csv').replace('\\', '\\\\')
 
-        self.storage_cmd('storage blob upload -f "{}" -c {} -n {}', account_info, csv_file, container, blob)
+        # test csv input
+        self.storage_cmd('storage blob upload -f "{}" -c {} -n {}', account_info, csv_file, container, csv_blob)
         query_string = "SELECT _2 from BlobStorage"
         result = self.storage_cmd('storage blob query -c {} -n {} --query-expression "{}"',
-                                  account_info, container, blob, query_string).output
+                                  account_info, container, csv_blob, query_string).output
         self.assertIsNotNone(result)
 
+        # test csv output
         temp_dir = self.create_temp_dir()
         result_file = os.path.join(temp_dir, 'result.csv')
         self.assertFalse(os.path.exists(result_file))
         self.storage_cmd('storage blob query -c {} -n {} --query-expression "{}" --result-file "{}"',
-                         account_info, container, blob, query_string, result_file)
+                         account_info, container, csv_blob, query_string, result_file)
         self.assertTrue(os.path.exists(result_file))
+
+        json_blob = self.create_random_name(prefix='jsonblob', length=12)
+        json_file = os.path.join(curr_dir, 'quick_query.json').replace('\\', '\\\\')
+
+        # test json input
+        self.storage_cmd('storage blob upload -f "{}" -c {} -n {}', account_info, json_file, container, json_blob)
+        query_string = "SELECT latitude FROM BlobStorage[*].warehouses[*]"
+        result = self.storage_cmd('storage blob query -c {} -n {} --query-expression "{}" --input-format json',
+                                  account_info, container, json_blob, query_string).output
+        self.assertIsNotNone(result)
